@@ -2,7 +2,7 @@ mod server;
 mod test_controller;
 mod test_struct;
 
-use netxclient::*;
+use netxclient::prelude::*;
 use log::LevelFilter;
 use server::*;
 use std::error::Error;
@@ -108,7 +108,8 @@ async fn main() -> Result<(), Box<dyn Error>> {
 
         for i in 0..100000 {
             //call!(@result client=>1000;1,2);
-            let _ = server.add(1, i).await?;
+            //let v =
+            server.add(1, i).await?;
             //println!("{}",v);
         }
 
